use chrono::{NaiveDate, NaiveTime};
use sqlx::{query, PgPool};

pub struct Availabillity {
    pub id: i32,
    pub user_id: i32,
    pub date: NaiveDate,
    pub start_time: Option<NaiveTime>,
    pub end_time: Option<NaiveTime>
}

impl Availabillity {
    pub async fn create(pool: &PgPool, user_id: i32, date: NaiveDate, start_time: Option<NaiveTime>, end_time: Option<NaiveTime>) -> anyhow::Result<i32> {
        let mut result = match (start_time, end_time) {
            (Some(start_time), Some(end_time)) => query!("INSERT INTO availabillity (userId, date, startTime, endTime) VALUES ($1, $2, $3, $4) RETURNING id;", user_id, date, start_time, end_time).fetch_one(pool).await?.id,
            (_, _) => query!("INSERT INTO availabillity (userId, date) VALUES ($1, $2) RETURNING id;", user_id, date).fetch_one(pool).await?.id
        };

        Ok(result)
    }

    pub async fn read_by_date(pool: &PgPool, date: NaiveDate) -> anyhow::Result<Vec<Availabillity>> {
        let records = query!("SELECT * FROM availabillity WHERE date = $1", date)
            .fetch_all(pool)
            .await?;

        let availabillities = records
            .iter()
            .map(|a| Availabillity {
                id: a.id,
                user_id: a.userid,
                date: a.date,
                start_time: a.starttime,
                end_time: a.endtime
            })
        .collect();

        Ok(availabillities)
    }
}
